=== modified file 'midori/midori-database.vala'
--- midori/midori-database.vala	2014-12-17 22:35:19 +0000
+++ midori/midori-database.vala	2015-03-15 16:24:41 +0000
@@ -45,7 +45,7 @@
         public virtual bool init (GLib.Cancellable? cancellable = null) throws DatabaseError {
             int result = database.db.prepare_v2 (query, -1, out _stmt, null);
             if (result != Sqlite.OK)
-                throw new DatabaseError.COMPILE ("Failed to compile statement: %s".printf (query));
+                throw new DatabaseError.COMPILE ("Failed to compile statement: %s".printf (database.db.errmsg ()));
             return true;
         }
 
@@ -57,6 +57,8 @@
          */
         public void bind (string pname, ...) throws DatabaseError {
             int pindex = stmt.bind_parameter_index (pname);
+            if (pindex <= 0)
+                throw new DatabaseError.TYPE ("No such parameter '%s' in statement: %s".printf (pname, query));
             var args = va_list ();
             Type ptype = args.arg ();
             if (ptype == typeof (string)) {
@@ -158,7 +160,7 @@
         internal bool trace = false;
         public Sqlite.Database? db { get { return _db; } }
         protected Sqlite.Database? _db = null;
-        public string? path { get; protected set; default = null; }
+        public string path { get; protected set; default = ":memory:"; }
 
         /*
          * A new database successfully opened for the first time.
@@ -170,13 +172,13 @@
          * If a filename is passed it's assumed to be in the config folder.
          * Otherwise the database is in memory only (useful for private browsing).
          */
-        public Database (string? path) throws DatabaseError {
+        public Database (string path=":memory:") throws DatabaseError {
             Object (path: path);
             init ();
         }
 
-        string resolve_path (string? path) {
-            if (path == null || path.has_prefix (":memory:"))
+        string resolve_path (string path) {
+            if (path.has_prefix (":memory:"))
                 return ":memory:";
             else if (!Path.is_absolute (path))
                 return Midori.Paths.get_config_filename_for_writing (path);
@@ -207,6 +209,9 @@
                 db.exec ("PRAGMA synchronous = NORMAL; PRAGMA temp_store = MEMORY;");
             db.exec ("PRAGMA count_changes = OFF;");
 
+            if (real_path == ":memory:")
+                return true;
+
             int64 user_version;
             Sqlite.Statement stmt;
             if (db.prepare_v2 ("PRAGMA user_version;", -1, out stmt, null) != Sqlite.OK)

=== added file 'tests/database.vala'
--- tests/database.vala	1970-01-01 00:00:00 +0000
+++ tests/database.vala	2015-03-15 16:24:41 +0000
@@ -0,0 +1,37 @@
+/*
+ Copyright (C) 2015 Christian Dywan <christian@twotoasts.de>
+
+ This library is free software; you can redistribute it and/or
+ modify it under the terms of the GNU Lesser General Public
+ License as published by the Free Software Foundation; either
+ version 2.1 of the License, or (at your option) any later version.
+
+ See the file COPYING for the full license text.
+*/
+
+class DatabaseTest : Midori.Test.Job {
+    public static void test () { new DatabaseTest ().run_sync (); }
+    public override async void run (Cancellable cancellable) throws GLib.Error {
+        var database = new Midori.Database ();
+        database.exec ("CREATE TABLE cats (cat text, favorite text)");
+        database.exec ("INSERT INTO cats (cat, favorite) VALUES ('Henry', 'pillow')");
+        var statement = database.prepare ("SELECT cat FROM cats WHERE favorite = :toy");
+        /* Missing : should throw an error */
+        try {
+            statement.bind ("toy", typeof (string), "pillow");
+        } catch (Midori.DatabaseError error) {
+            Katze.assert_str_equal (statement.query, error.message,
+                "No such parameter 'toy' in statement: " + statement.query);
+        }
+        statement.bind (":toy", typeof (string), "pillow");
+    }
+}
+
+void main (string[] args) {
+    Midori.Test.init (ref args);
+    Midori.App.setup (ref args, null);
+    Midori.Paths.init (Midori.RuntimeMode.NORMAL, null);
+    Test.add_func ("/database/bind", DatabaseTest.test);
+    Test.run ();
+}
+

